@@ -529,8 +529,13 @@ class PlaywrightState(LibraryComponent):
                 )
             )
         logger.info(response.log)
-        self.context_cache.add(response.body, self._get_video_size(params))
-        return response.body
+        if response.newBrowser:
+            logger.info(
+                "No browser was open. New browser was automatically opened "
+                "when this context is created."
+            )
+        self.context_cache.add(response.id, self._get_video_size(params))
+        return response.id
 
     def _set_video_path(self, params: dict) -> dict:
         video_path = params.get("videosPath")
@@ -579,7 +584,6 @@ class PlaywrightState(LibraryComponent):
         and `New Context` are executed with default values first.
 
         ``url`` If specified it will open the new page to the specified URL.
-
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.NewPage(
@@ -589,6 +593,16 @@ class PlaywrightState(LibraryComponent):
                 Request().Url(url=(url or ""), defaultTimeout=int(self.timeout))
             )
         logger.info(response.log)
+        if response.newBrowser:
+            logger.info(
+                "No browser and context was open. New browser and context was "
+                "automatically opened when page is created."
+            )
+        if response.newContext and not response.newBrowser:
+            logger.info(
+                "No context was open. New context was automatically opened when "
+                "this page is created."
+            )
         self._embed_video(json.loads(response.video))
         return response.body
 
