@@ -13,8 +13,8 @@
 # limitations under the License.
 
 import json
+import time
 from datetime import timedelta
-from pathlib import Path
 from typing import Dict, Optional, Union
 
 from ..base import LibraryComponent
@@ -72,15 +72,23 @@ class Waiter(LibraryComponent):
             ElementState.visible,
             ElementState.hidden,
         ]:
-            try:
-                self._wait_for_elements_state(selector, state, timeout)
-            except Exception:
-                if message:
-                    message = message.format(
-                        selector=selector, function=state, timeout=timeout
-                    )
-                    raise AssertionError(message)
-                raise
+            end = float(
+                self.convert_timeout(timeout, False) if timeout else self.timeout / 1000
+            )
+            end += time.monotonic()
+            while True:
+                try:
+                    return self._wait_for_elements_state(selector, state, timeout)
+                except Exception as error:
+                    if end > time.monotonic():
+                        logger.debug(f"Suppress error: {error}")
+                    else:
+                        if message:
+                            message = message.format(
+                                selector=selector, function=state, timeout=timeout
+                            )
+                            raise AssertionError(message)
+                        raise
         else:
             self.wait_for_function(
                 funct[state], selector=selector, timeout=timeout, message=message
@@ -138,15 +146,23 @@ class Waiter(LibraryComponent):
         | Click         \\#progress_bar
         | Wait For      ${promise}
         """
-        try:
-            self._wait_for_function(function, selector, polling, timeout)
-        except Exception:
-            if message:
-                message = message.format(
-                    selector=selector, function=function, timeout=timeout
-                )
-                raise AssertionError(message)
-            raise
+        end = float(
+            self.convert_timeout(timeout, False) if timeout else self.timeout / 1000
+        )
+        end += time.monotonic()
+        while True:
+            try:
+                return self._wait_for_function(function, selector, polling, timeout)
+            except Exception as error:
+                if end > time.monotonic():
+                    logger.debug(f"Suppress {error}")
+                else:
+                    if message:
+                        message = message.format(
+                            selector=selector, function=function, timeout=timeout
+                        )
+                        raise AssertionError(message)
+                    raise
 
     def _wait_for_function(
         self,
@@ -171,32 +187,3 @@ class Waiter(LibraryComponent):
             )
             logger.debug(response.json)
             logger.info(response.log)
-
-    @keyword(tags=("Wait", "BrowserControl"))
-    def wait_for_download(self, saveAs: str = "") -> str:
-        """Waits for next download event on page. Returns file path to downloaded file.
-
-        To enable downloads context's ``acceptDownloads`` needs to be true.
-
-        With default filepath downloaded files are deleted when Context the download happened in is closed.
-
-        ``saveAs`` Filename to save as. File will also temporarily be saved in playwright context's default download location.
-
-        Example usage:
-        | New Context      acceptDownloads=True
-        | New Page         ${LOGIN_URL}
-        | ${dl_promise}    Promise To  Wait For Download
-        | Click            \\#file_download
-        | ${file_path}=    Wait For  ${dl_promise}
-        """
-        with self.playwright.grpc_channel() as stub:
-            if not saveAs:
-                response = stub.WaitForDownload(Request().FilePath())
-                logger.debug(response.log)
-                return json.loads(response.json)
-            else:
-                p = Path(saveAs)
-                p.resolve()
-                response = stub.WaitForDownload(Request().FilePath(path=str(p)))
-                logger.debug(response.log)
-                return json.loads(response.json)
