@@ -13,7 +13,7 @@
 # limitations under the License.
 
 from enum import Enum, auto
-from typing import Dict, Union
+from typing import Dict, Tuple, Union
 
 from typing_extensions import TypedDict
 
@@ -59,6 +59,11 @@ def convert_typed_dict(function_annotations: Dict, params: Dict) -> Dict:
     return params
 
 
+class DelayedKeyword(TypedDict):
+    name: str
+    args: Tuple[str, ...]
+
+
 class BoundingBox(TypedDict, total=False):
     x: float
     y: float
@@ -473,3 +478,11 @@ class ScreenshotFileTypes(Enum):
 
     png = auto()
     jpeg = auto()
+
+
+class PageLoadStates(Enum):
+    """Enum that defines available page load states."""
+
+    load = auto()
+    domcontentloaded = auto()
+    networkidle = auto()
